@@ -1,6 +1,6 @@
 """这是nester.py模块,提供了一个名为print_lol()的函数,这个函数的作用是打印列
 表，其中有可能包含（也可能不包含）嵌套列表。"""
-def print_lol(the_list,level):
+def print_lol(the_list,level=0):
         """这个函数有一个位置参数,名为 'the_list',
         这可以是任何python列表(也可以是包含嵌套列表的列表),
         另一个缩进参数,名为level,用于控制缩进次数（在屏幕上显示一行数据时需要加多少个制表符tab）
